@@ -4,7 +4,7 @@
 int main(int argc, char *argv[])
 {
     QApplication a(argc, argv);
-    WoLAN w;
+    wolan w;
 #if defined(Q_WS_S60)
     w.showMaximized();
 #else
